@@ -20,35 +20,21 @@ import shutil
 import hashlib
 
 from newtools.aws import S3Location
-from newtools.optional_imports import s3fs, SqlClient, AthenaClient
+from newtools.optional_imports import SqlClient, AthenaClient
+from newtools.doggo import DoggoLock, DoggoFileSystem
 
 logger = logging.getLogger("dativa.attribution.cached_query")
 
-class S3fsMixin:
-    """Provides a simple class to get a non-caching S3FS file system object"""
-    __s3fs = None
-
-    @property
-    def _s3fs(self):
-        """
-        S3FS caching does not respect other applications updating S3 so therefore we invalidate
-        the cache before using
-
-        :return: the S3FS File system
-        """
-        if self.__s3fs is None:
-            s3fs.S3FileSystem.read_timeout = 600
-            self.__s3fs = s3fs.S3FileSystem()
-
-        self.__s3fs.invalidate_cache()
-        return self.__s3fs
+# Set S3fsMixin for backwards compatibility
+S3fsMixin = DoggoFileSystem
 
 
-class BaseCachedClass(S3fsMixin):
+class BaseCachedClass:
     validation_mode = False
 
     def __init__(self, cache_path):
         self.cache_path = cache_path
+        self.dfs = DoggoFileSystem()
 
     def _exists(self, path):
         """
@@ -59,12 +45,8 @@ class BaseCachedClass(S3fsMixin):
         """
         if self.validation_mode:
             return True
-        elif path.startswith("s3://"):
-            return self._s3fs.exists(path)
-        elif os.path.exists(path):
-            return True
-
-        return False
+        else:
+            return self.dfs.exists(path)
 
     @staticmethod
     def _get_file_hash(files):
@@ -122,6 +104,10 @@ class BaseCachedClass(S3fsMixin):
 class BaseCachedQuery(BaseCachedClass):
     _archive_path = None
 
+    wait_period = 30
+    time_out_seconds = 1800
+    maximum_age = 3600
+
     def __init__(self, params=None, cache_path="", sql_archive_path=None, sql_paths=None, gzip=True):
         """
         Cached query class
@@ -253,11 +239,12 @@ class BaseCachedQuery(BaseCachedClass):
             data_hash=self._get_dict_hash(params, replacement_dict),
             suffix=".gz" if self._gzip else "")
 
-        if self._exists(path):
-            if path.startswith("s3://"):
-                self._s3fs.rm(path)
-            else:
-                os.remove(path)
+        with DoggoLock(path,
+                       wait_period=self.wait_period,
+                       time_out_seconds=self.time_out_seconds,
+                       maximum_age=self.maximum_age):
+            if self._exists(path):
+                self.dfs.rm(path)
 
     @staticmethod
     def _validate_sql(sql_file):
@@ -303,35 +290,39 @@ class BaseCachedQuery(BaseCachedClass):
             data_hash=self._get_dict_hash(params, replacement_dict),
             suffix=".gz" if self._gzip else "")
 
-        logger.info("Caching query to {0}".format(output_file))
         self._log_parameters(params)
 
         if not self._exists(output_file):
-            # clean up any S3 files with the same prefix
-            if output_file.startswith("s3://"):
-                for file in self._s3fs.glob(output_file + "**"):
-                    self._s3fs.rm(file)
+            # Get the file file lock
+            with DoggoLock(output_file,
+                           wait_period=self.wait_period,
+                           time_out_seconds=self.time_out_seconds,
+                           maximum_age=self.maximum_age):
+                # Check to see if it exists...
+                if not self._exists(output_file):
+                    # clean up any S3 files with the same prefix
+                    for file in self.dfs.glob(output_file + "**"):
+                        self.dfs.rm(file)
 
-            logger.info("Executing query to {0}".format(output_file))
-            self._execute_query(query_file=file_path,
-                                output_file=output_file,
-                                query_parameters=query_parameters,
-                                replacement_dict={} if replacement_dict is None else replacement_dict)
+                    logger.info("Executing query to {0}".format(output_file))
+                    self._execute_query(query_file=file_path,
+                                        output_file=output_file,
+                                        query_parameters=query_parameters,
+                                        replacement_dict={} if replacement_dict is None else replacement_dict)
 
-            # In the S3 case, redshift files are saved with a prefix and need to be renamed
-            if output_file.startswith("s3://"):
-                if not self._s3fs.exists(output_file):
-                    files = self._s3fs.glob(output_file + "**")
-                    if len(files) == 0:
-                        raise ValueError("No file returned by the query. Does it contain an UNLOAD command?")
-                    elif len(files) > 1:
-                        raise ValueError(
-                            "More than one file produced by query. Is PARALLEL OFF set in your UNLOAD command?")
-                    else:
-                        self._s3fs.mv(files[0], output_file)
-        else:
-            logger.info("Loading cached query from {0}".format(output_file))
+                    # In the S3 case, redshift files are saved with a prefix and need to be renamed
+                    if output_file.startswith("s3://"):
+                        if not self.dfs.exists(output_file):
+                            files = self.dfs.glob(output_file + "**")
+                            if len(files) == 0:
+                                raise ValueError("No file returned by the query. Does it contain an UNLOAD command?")
+                            elif len(files) > 1:
+                                raise ValueError(
+                                    "More than one file produced by query. Is PARALLEL OFF set in your UNLOAD command?")
+                            else:
+                                self.dfs.mv(files[0], output_file)
 
+        logger.info("Loading query from {0}".format(output_file))
         return output_file
 
     def _execute_query(self, **params):
@@ -415,7 +406,7 @@ class CachedAthenaQuery(BaseCachedQuery):
         if self.__ac is None:
             self.__ac = AthenaClient(region=self._args.get('aws_region', 'us-east-1'),
                                      db=self._args['athena_db'],
-                                     workgroup=self._args.get('workgroup',None))
+                                     workgroup=self._args.get('workgroup', None))
 
         return self.__ac
 
@@ -427,15 +418,10 @@ class CachedAthenaQuery(BaseCachedQuery):
         :param parameters: the parameters to apply
         :param file: the archive file path
         """
-        if file.startswith("s3"):
-            op_func = self._s3fs.open
-        else:
-            op_func = open
-
-        with op_func(file, 'wt') as f:
-            f.write('-- Ran query on: {:%Y-%m-%d %H:%M:%S}\n'.format(datetime.datetime.now()))
-            f.write('-- Parameters: {0}\n'.format(self._clean_dict(parameters)))
-            f.write(logged_query + ';\n')
+        with self.dfs.open(file, 'wb') as f:  # FileDoggo does not support "wt" for S3 files
+            f.write('-- Ran query on: {:%Y-%m-%d %H:%M:%S}\n'.format(datetime.datetime.now()).encode('UTF-8'))
+            f.write('-- Parameters: {0}\n'.format(self._clean_dict(parameters)).encode('UTF-8'))
+            f.write((logged_query + ';\n').encode('UTF-8'))
 
     def _execute_query(self,
                        query_file,
@@ -481,11 +467,11 @@ class CachedAthenaQuery(BaseCachedQuery):
         # gzip the output
         if self._gzip:
             gz_file = output_file
-            with self._s3fs.open(actual_file, 'rb') as f_in:
-                with self._s3fs.open(gz_file, 'wb') as f_out:
+            with self.dfs.open(actual_file, 'rb') as f_in:
+                with self.dfs.open(gz_file, 'wb') as f_out:
                     with gz.open(f_out, 'wb') as gz_out:
                         shutil.copyfileobj(f_in, gz_out)
 
         # delete the metadata file
-        self._s3fs.rm(actual_file)
-        self._s3fs.rm(actual_file + '.metadata')
+        self.dfs.rm(actual_file)
+        self.dfs.rm(actual_file + '.metadata')
