@@ -118,6 +118,17 @@ def get_pandas():
 
 pandas = get_pandas()
 
+
+# -----------------------------
+@import_wrapper(DummyClass("numpy"))
+def get_numpy():
+    import numpy
+    return numpy
+
+
+numpy = get_numpy()
+
+
 # -----------------------------
 
 @import_wrapper(DummyClass("pyarrow"))
@@ -128,6 +139,7 @@ def get_pyarrow():
 
 pyarrow = get_pyarrow()
 
+
 # -----------------------------
 
 @import_wrapper(DummyClass("boto3"))
@@ -135,8 +147,18 @@ def get_boto3():
     import boto3
     return boto3
 
+
 boto3 = get_boto3()
 
+
+@import_wrapper(DummyClass("chardet.universaldetector"))
+def get_universal_detector():
+    from chardet.universaldetector import UniversalDetector
+    return  UniversalDetector
+
+
+UniversalDetector = get_universal_detector()
+
 # -----------------------------
 
-#  Add new optional imports to the bottom of this file together with the dummy class
\ No newline at end of file
+#  Add new optional imports to the bottom of this file together with the dummy class
