@@ -6,28 +6,47 @@ This code is licensed under MIT license (see license.txt for details)
 
 import sqlite3
 import os
+from time import time
 
 from datetime import datetime, timedelta
 
 from .base_test import BaseTest
-from newtools import CachedPep249Query, CachedAthenaQuery, BaseCachedQuery, PandasDoggo
+from newtools import CachedPep249Query, CachedAthenaQuery, BaseCachedQuery, PandasDoggo, DoggoFileSystem
 
 
 class TestCachedQuery(BaseTest):
-    s3_bucket = "s3://aws-athena-query-results-933373196108-us-west-2/"
     region = "us-west-2"
     athena_db_name = "sampledb"
 
+    @classmethod
+    def setUpClass(cls):
+        cls.s3_bucket = "s3://aws-athena-query-results-933373196108-us-west-2/{0}/".format(time())
+        super(TestCachedQuery, cls).setUpClass()
+
+    @classmethod
+    def tearDownClass(cls):
+        dfs = DoggoFileSystem()
+        for file in dfs.glob(cls.s3_bucket + "**"):
+            dfs.rm(file)
+        super(TestCachedQuery, cls).tearDownClass()
+
     def setUp(self):
-        super().setUp()
         self.sqlite_db = sqlite3.connect(os.path.join(self.test_dir, "query_tests", "test.sqlite"))
         self.sql_path = os.path.join(self.test_dir, "query_tests")
+        super(TestCachedQuery, self).setUp()
+
+    @staticmethod
+    def set_timeouts(q):
+        q.wait_period = 0
+        q.time_out_seconds = 1
+        q.maximum_age = 120
 
     def test_bad_path_pep249(self):
         q = CachedPep249Query(self.sqlite_db,
                               cache_path=self.tempdir,
                               sql_paths=[self.sql_path],
                               gzip=False)
+        self.set_timeouts(q)
 
         with self.assertRaises(ValueError):
             q.get_results(sql_file="bad_query.sql",
@@ -39,6 +58,7 @@ class TestCachedQuery(BaseTest):
                               cache_path=self.tempdir,
                               sql_paths=[self.sql_path],
                               gzip=False)
+        self.set_timeouts(q)
 
         with self.assertLogs("dativa.attribution.cached_query", level="INFO") as cm:
             q.get_results(sql_file="test_select.sql",
@@ -55,6 +75,7 @@ class TestCachedQuery(BaseTest):
                               cache_path=self.tempdir,
                               sql_paths=[self.sql_path],
                               gzip=False)
+        self.set_timeouts(q)
 
         a = q.get_results(sql_file="test_select.sql",
                           output_prefix="test_query",
@@ -64,6 +85,7 @@ class TestCachedQuery(BaseTest):
         q2 = BaseCachedQuery(cache_path=self.tempdir,
                              sql_paths=[self.sql_path],
                              gzip=False)
+        self.set_timeouts(q2)
 
         b = q2.get_results(sql_file="test_select.sql",
                            output_prefix="test_query",
@@ -85,6 +107,7 @@ class TestCachedQuery(BaseTest):
                               cache_path=self.tempdir,
                               sql_paths=[self.sql_path],
                               gzip=False)
+        self.set_timeouts(q)
 
         q.get_results(sql_file="test_select.sql",
                       output_prefix="test_query",
@@ -112,6 +135,7 @@ class TestCachedQuery(BaseTest):
                               sql_paths=[self.sql_path],
                               params={"sql_archive_path": os.path.join(self.tempdir, "new")},
                               gzip=False)
+        self.set_timeouts(q)
 
         q.get_results(sql_file="test_select.sql",
                       output_prefix="test_query"
@@ -125,6 +149,7 @@ class TestCachedQuery(BaseTest):
                               cache_path=self.tempdir,
                               sql_paths=[self.sql_path],
                               gzip=False)
+        self.set_timeouts(q)
 
         q.get_results(sql_file="test_select_in.sql",
                       output_prefix="test_query_1_row",
@@ -138,6 +163,7 @@ class TestCachedQuery(BaseTest):
                               cache_path=self.tempdir,
                               sql_paths=[self.sql_path],
                               gzip=False)
+        self.set_timeouts(q)
 
         q.get_results(sql_file="test_select_s3_path.sql",
                       output_prefix="test_query_0_rows",
@@ -154,6 +180,7 @@ class TestCachedQuery(BaseTest):
                               sql_paths=[self.sql_path],
                               sql_archive_path=self.tempdir,
                               gzip=False)
+        self.set_timeouts(q)
 
         q.get_results(sql_file="test_select.sql",
                       output_prefix="test_query",
@@ -172,6 +199,7 @@ class TestCachedQuery(BaseTest):
                               cache_path=self.s3_bucket,
                               sql_paths=[self.sql_path],
                               sql_archive_path=self.tempdir)
+        self.set_timeouts(q)
 
         days = [datetime.utcnow() - timedelta(days=1),
                 datetime.utcnow(),
@@ -219,6 +247,7 @@ class TestCachedQuery(BaseTest):
                                       "athena_db": self.athena_db_name},
                               cache_path=self.s3_bucket,
                               sql_paths=[self.sql_path], )
+        self.set_timeouts(q)
 
         days = [datetime.utcnow() - timedelta(days=1),
                 datetime.utcnow(),
@@ -243,6 +272,7 @@ class TestCachedQuery(BaseTest):
                               cache_path=self.s3_bucket,
                               sql_paths=[self.sql_path],
                               sql_archive_path=self.s3_bucket)
+        self.set_timeouts(q)
 
         # use a list of length one
         days = [datetime.utcnow()]
@@ -251,7 +281,7 @@ class TestCachedQuery(BaseTest):
                       output_prefix="athena_test",
                       params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
         try:
-            q._s3fs.rm(os.path.join(self.s3_bucket, "athena_test.sql"))
+            DoggoFileSystem().rm(os.path.join(self.s3_bucket, "athena_test.sql"))
         except FileNotFoundError:
             pass
 
@@ -260,7 +290,8 @@ class TestCachedQuery(BaseTest):
                       params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
 
         # check the archive.
-        query = q._s3fs.open(os.path.join(self.s3_bucket, "athena_test.sql"), "rt").read()
+        with DoggoFileSystem().open(os.path.join(self.s3_bucket, "athena_test.sql"), "rb") as f:
+            query = f.read().decode("UTF-8")
 
         self.assertIn("-- Ran query on:", query)
         self.assertIn("-- Parameters: {'aws_region': 'us-west-2'", query)
@@ -288,6 +319,7 @@ class TestCachedQuery(BaseTest):
                                        "athena_db": self.athena_db_name},
                                cache_path=self.s3_bucket,
                                sql_paths=[self.sql_path], )
+        self.set_timeouts(q)
 
         days = [datetime.utcnow() - timedelta(days=1),
                 datetime.utcnow(),
@@ -328,7 +360,7 @@ class TestCachedQuery(BaseTest):
                     replacement_dict=replacement_dict
                 )
 
-                self._s3fs.cp(output_file + "000.gz", output_file + "001.gz")
+                DoggoFileSystem().cp(output_file + "000.gz", output_file + "001.gz")
 
                 return a
 
@@ -336,6 +368,7 @@ class TestCachedQuery(BaseTest):
                                                "athena_db": self.athena_db_name, },
                                        cache_path=self.s3_bucket,
                                        sql_paths=[self.sql_path], )
+        self.set_timeouts(q)
 
         days = [datetime.utcnow()]
 
@@ -368,7 +401,7 @@ class TestCachedQuery(BaseTest):
                     replacement_dict=replacement_dict
                 )
 
-                self._s3fs.rm(output_file)
+                DoggoFileSystem().rm(output_file)
 
                 return a
 
@@ -376,6 +409,7 @@ class TestCachedQuery(BaseTest):
                                            "athena_db": self.athena_db_name},
                                    cache_path=self.s3_bucket,
                                    sql_paths=[self.sql_path], )
+        self.set_timeouts(q)
 
         days = [datetime.utcnow()]
 
@@ -396,6 +430,7 @@ class TestCachedQuery(BaseTest):
                               sql_paths=[self.sql_path],
                               sql_archive_path=self.tempdir,
                               gzip=False)
+        self.set_timeouts(q)
 
         with self.assertRaisesRegex(ValueError, "contains unescaped % signs that will not run"):
             q.get_results(sql_file="test_select_bad.sql",
