@@ -1,4 +1,4 @@
-# (c) 2012-2018 The company fomerly known as Dativa, all rights reserved
+# (c) 2012-2018 Dativa, all rights reserved
 # -----------------------------------------
 #  This code is licensed under MIT license (see license.txt for details)
 
@@ -6,13 +6,17 @@ import unittest
 import os
 import pyarrow as pa
 
-import pandas as pd
-import numpy as np
+from time import sleep
+import multiprocessing
+from random import random
 import gzip
-import boto3
-from pandas.testing import assert_frame_equal
 
-from newtools import PandasDoggo, FileDoggo, S3Location
+from newtools.optional_imports import pandas as pd
+from newtools.optional_imports import numpy as np
+from newtools.optional_imports import boto3
+
+from newtools import PandasDoggo, FileDoggo, S3Location, DoggoFileSystem, DoggoLock, DoggoWait
+from .base_test import BaseTest
 
 
 class TestDoggos(unittest.TestCase):
@@ -31,7 +35,7 @@ class TestDoggos(unittest.TestCase):
         session = boto3.Session()
         fh = PandasDoggo(boto_session=session)
         df = fh.load(pth)
-        assert_frame_equal(df, expected_df)
+        pd.testing.assert_frame_equal(df, expected_df)
 
     def test_read_csv_local_gzip(self):
         pth = os.path.join(self.base_path, 'csv', 'gzip', 'test.csv.gz')
@@ -66,13 +70,18 @@ class TestDoggos(unittest.TestCase):
 
         os.remove(pth_out)
 
-
     def test_read_csv_local_gzip_infer(self):
         pth = os.path.join(self.base_path, 'csv', 'gzip', 'test.csv.gz')
 
         fh = PandasDoggo()
         df = fh.load(pth)
 
+    def test_read_csv_local_zip_infer(self):
+        with self.assertRaises(NotImplementedError):
+            pth = os.path.join(self.base_path, 'csv', 'gzip', 'test.csv.zip')
+            fh = PandasDoggo()
+            df = fh.load(pth)
+
     def test_write_csv_local(self):
         df = pd.DataFrame({'e-mail': {0: 'n@gmail.com', 1: 'p@gmail.com', 2: 'h@gmail.com', 3: 's@gmail.com',
                                       4: 'l@gmail.com', 5: 'v@gmail.com', 6: None},
@@ -118,7 +127,7 @@ class TestDoggos(unittest.TestCase):
 
         fh.save_parquet(test_df, new_file_path, schema=my_schema)
 
-        assert_frame_equal(test_df, fh.load_parquet(new_file_path))
+        pd.testing.assert_frame_equal(test_df, fh.load_parquet(new_file_path))
         os.remove(new_file_path)
 
     def test_pq_schema_int32(self):
@@ -138,16 +147,16 @@ class TestDoggos(unittest.TestCase):
 
         fh.save_parquet(test_df, new_file_path, schema=my_schema)
 
-        assert_frame_equal(test_df, fh.load_parquet(new_file_path))
+        pd.testing.assert_frame_equal(test_df, fh.load_parquet(new_file_path))
         os.remove(new_file_path)
 
     def test_pq_schema_int32_nulls(self):
-
         new_file_path = os.path.join(self.base_path,
                                      'parquet',
                                      'new_data_nulls.parquet')
         test_df = pd.DataFrame(
-            {"col1": pd.Series([1, 2, 3, 4, 128, pd.NA, None], dtype='Int32'), "col2": ["a", "s", "6", "7", "t", 'pd.NA', 'None']})
+            {"col1": pd.Series([1, 2, 3, 4, 128, pd.NA, None], dtype='Int32'),
+             "col2": ["a", "s", "6", "7", "t", 'pd.NA', 'None']})
         fields = [
             pa.field("col1", pa.int32()),
             pa.field("col2", pa.string())
@@ -158,7 +167,7 @@ class TestDoggos(unittest.TestCase):
 
         fh.save_parquet(test_df, new_file_path, schema=my_schema)
 
-        assert_frame_equal(test_df, fh.load_parquet(new_file_path))
+        pd.testing.assert_frame_equal(test_df, fh.load_parquet(new_file_path))
         os.remove(new_file_path)
 
     def test_pq_schema_int64_nulls(self):
@@ -178,7 +187,7 @@ class TestDoggos(unittest.TestCase):
 
         fh.save_parquet(test_df, new_file_path, schema=my_schema)
 
-        assert_frame_equal(test_df, fh.load_parquet(new_file_path))
+        pd.testing.assert_frame_equal(test_df, fh.load_parquet(new_file_path))
         os.remove(new_file_path)
 
     def test_pq_schema_datetime(self):
@@ -198,7 +207,7 @@ class TestDoggos(unittest.TestCase):
 
         fh.save_parquet(test_df, new_file_path, schema=my_schema)
 
-        assert_frame_equal(test_df, fh.load_parquet(new_file_path))
+        pd.testing.assert_frame_equal(test_df, fh.load_parquet(new_file_path))
         os.remove(new_file_path)
 
     def test_read_csv_s3(self):
@@ -210,7 +219,7 @@ class TestDoggos(unittest.TestCase):
         session = boto3.Session()
         fh = PandasDoggo(boto_session=session)
         df = fh.load(pth)
-        assert_frame_equal(df, expected_df)
+        pd.testing.assert_frame_equal(df, expected_df)
 
     def test_write_csv_s3(self):
         df = pd.DataFrame({'e-mail': {0: 'n@gmail.com', 1: 'p@gmail.com', 2: 'h@gmail.com', 3: 's@gmail.com',
@@ -237,7 +246,7 @@ class TestDoggos(unittest.TestCase):
 
         fh.save(df, pth, index=None, compression="gzip")
 
-        assert_frame_equal(fh.load_csv(pth), df)
+        pd.testing.assert_frame_equal(fh.load_csv(pth), df)
 
         s3 = boto3.resource('s3')
         obj = s3.Object(pth.bucket, pth.key)
@@ -251,7 +260,7 @@ class TestDoggos(unittest.TestCase):
         pth_local = os.path.join(self.base_path, 'parquet', 'data.parquet')
         df_l = fh.load_parquet(pth_local)
 
-        assert_frame_equal(df_s3, df_l)
+        pd.testing.assert_frame_equal(df_s3, df_l)
 
     def test_write_pq_s3(self):
         fh = PandasDoggo()
@@ -286,3 +295,130 @@ class TestDoggos(unittest.TestCase):
         with self.assertRaises(ValueError):
             with FileDoggo('some_path_to_a_file', mode='justusewb', is_s3=True) as f:
                 f.write('should have read the docs')
+
+
+class TestCSVDoggo(unittest.TestCase):
+    pass
+
+
+class TestDoggoFileSystem(BaseTest):
+
+    def _test(self, root):
+        dfs = DoggoFileSystem()
+
+        testdir = dfs.join(root, str(random()))
+
+        file_1 = dfs.join(testdir, "temp_1.txt")
+        file_2 = dfs.join(testdir, "tests", "temp_2.txt")
+
+        self.assertEqual(dfs.split(file_1), (testdir, "temp_1.txt"))
+
+        self.assertFalse(dfs.exists(file_1))
+        self.assertFalse(dfs.exists(file_2))
+
+        with dfs.open(file_1, "wb") as f:
+            f.write(b"woof")
+
+        self.assertTrue(dfs.exists(file_1))
+        self.assertFalse(dfs.exists(file_2))
+
+        dfs.cp(file_1, file_2)
+        self.assertTrue(dfs.exists(file_1))
+        self.assertTrue(dfs.exists(file_2))
+
+        paths = dfs.glob(dfs.join(testdir, "**"))
+        self.assertIn(file_1, paths)
+        self.assertIn(file_2, paths)
+
+        dfs.rm(file_2)
+        self.assertTrue(dfs.exists(file_1))
+        self.assertFalse(dfs.exists(file_2))
+
+        dfs.mv(file_1, file_2)
+        self.assertFalse(dfs.exists(file_1))
+        self.assertTrue(dfs.exists(file_2))
+
+        self.assertEqual(dfs.size(file_2), 4)
+
+    def test_s3(self):
+        self._test(S3Location("s3://07092018pqtest/fs/"))
+
+        dfs = DoggoFileSystem()
+        self.assertEqual(dfs.split("s3://07092018pqtest/temp.txt"), ("s3://07092018pqtest/", "temp.txt"))
+
+    def test_file(self):
+        self._test(self.tempdir)
+
+    def test_bad_copy(self):
+        with self.assertRaises(NotImplementedError):
+            DoggoFileSystem().cp("s3://07092018pqtest/fs/file.tmp",
+                                 os.path.join(self.tempdir, "file.tmp"))
+
+
+class TestDoggoWait(unittest.TestCase):
+    def test_basic(self):
+        dw = DoggoWait(wait_period=1, time_out_seconds=2)
+
+        with self.assertRaises(ValueError):
+            dw.timed_out()
+
+        dw.start_timeout()
+        self.assertEqual(dw.timed_out(), False)
+        dw.check_timeout()
+        dw.wait()
+        with self.assertRaises(TimeoutError):
+            dw.check_timeout()
+
+
+def check_lock(file):
+    test_str = str(random())
+    with DoggoLock(file, wait_period=1, time_out_seconds=2, maximum_age=5):
+        with open(file, "wt") as f:
+            f.write(test_str)
+
+        with open(file, "rt") as f:
+            assert f.read() == test_str
+
+        sleep(0.1)
+
+
+class TestDoggoLock(BaseTest):
+    def test_lock_timeout(self):
+        file = os.path.join(self.tempdir, 'test_lock_timeout.tmp')
+        with DoggoLock(file, wait_period=1, time_out_seconds=5, maximum_age=10):
+            with self.assertRaises(TimeoutError):
+                with DoggoLock(file, wait_period=1, time_out_seconds=5, maximum_age=10):
+                    pass
+
+    def test_basic(self):
+        file = os.path.join(self.tempdir, 'test_basic.tmp')
+        check_lock(file)
+        check_lock(file)
+
+    def test_lock_ages(self):
+        file = os.path.join(self.tempdir, 'test_lock_ages.tmp')
+        lock_1 = DoggoLock(file, wait_period=1, time_out_seconds=2, maximum_age=5)
+        lock_2 = DoggoLock(file, wait_period=1, time_out_seconds=2, maximum_age=5)
+
+        lock_1.acquire()
+
+        with self.assertRaises(TimeoutError):
+            lock_2.acquire()
+
+        sleep(5)
+
+        lock_2.acquire()
+
+        lock_1.release()
+        lock_2.release()
+
+    def test_lock_multiprocess(self):
+        file = os.path.join(self.tempdir, 'test_lock_multiprocess.tmp')
+        pool = multiprocessing.Pool()
+
+        for _ in range(0, 100):
+            pool.apply_async(check_lock,
+                             (file,))
+
+        pool.close()
+        pool.join()
